"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Configuration_1 = require("../../Configuration/Configuration");
class SecurityService {
    constructor(options) {
        this._accessRules = [];
        this._accessRulesLocalStorageName = options && options.accessRulesLocalStorageName ? options.accessRulesLocalStorageName : "accessRules";
        this._accessRules = this.GetAccessRules(this._accessRulesLocalStorageName);
        this._currentUserStorageItem = options && options.currentUserStorageItem ? options.currentUserStorageItem : "currentUser";
    }
    get CurrentUser() {
        const currentUserFromLocalStorage = localStorage.getItem(this._currentUserStorageItem);
        if (currentUserFromLocalStorage) {
            const value = JSON.parse(currentUserFromLocalStorage);
            return value;
        }
        return null;
    }
    GetAccessRules(name) {
        const rulesString = localStorage.getItem(name);
        return rulesString ? JSON.parse(rulesString.toLocaleLowerCase()) : [];
    }
    UserHasAccessRule(accessRuleName) {
        return this._accessRules.indexOf(accessRuleName.toLocaleLowerCase()) !== -1;
    }
    UserHasAccessRuleStartsWith(accessRuleStarts) {
        const query = new RegExp(`\^${accessRuleStarts}`, "i");
        return this._accessRules.some(accessRule => query.test(accessRule));
    }
    UserHasAnyAccessRuleStartsWith(accessRuleStarts) {
        return accessRuleStarts.some(start => this.UserHasAccessRuleStartsWith(start));
    }
    UserHasAnyAccessRule(accessRuleNames) {
        return accessRuleNames.some(rule => this._accessRules.indexOf(rule.toLocaleLowerCase()) !== -1);
    }
    MapAccessProxy(accessProxyClass) {
        if (accessProxyClass[Configuration_1.CONFIGURATION.AccessProxyVisibleRulesName]) {
            for (const key in accessProxyClass[Configuration_1.CONFIGURATION.AccessProxyVisibleRulesName]) {
                if (accessProxyClass[Configuration_1.CONFIGURATION.AccessProxyVisibleRulesName][key]) {
                    const rules = accessProxyClass[Configuration_1.CONFIGURATION.AccessProxyVisibleRulesName][key];
                    accessProxyClass.visible[key] = Array.isArray(rules) ? this.UserHasAnyAccessRule(rules) : this.UserHasAccessRule(rules);
                }
            }
        }
        if (accessProxyClass[Configuration_1.CONFIGURATION.AccessProxyWritableRulesName]) {
            for (const key in accessProxyClass[Configuration_1.CONFIGURATION.AccessProxyWritableRulesName]) {
                if (accessProxyClass[Configuration_1.CONFIGURATION.AccessProxyWritableRulesName][key]) {
                    const rules = accessProxyClass[Configuration_1.CONFIGURATION.AccessProxyWritableRulesName][key];
                    if (!accessProxyClass.writable[key]) {
                        accessProxyClass.writable[key] = Array.isArray(rules) ? this.UserHasAnyAccessRule(rules) : this.UserHasAccessRule(rules);
                    }
                }
            }
        }
        return accessProxyClass;
    }
}
exports.SecurityService = SecurityService;
