"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class TokenService {
    constructor(localStorageTokenName) {
        this._localStorageTokenName = localStorageTokenName ? localStorageTokenName : "token";
    }
    getTokenFromCookie(name, source) {
        const matches = source.match(new RegExp("(?:^|; )" + name.replace(/([\.$?*|{}\(\)\[\]\\\/\+^])/g, "\\$1") + "=([^;]*)"));
        const cookie = matches ? decodeURIComponent(matches[1]) : null;
        return cookie;
    }
    getTokenFromLocalStorage(name) {
        return localStorage.getItem(this._localStorageTokenName);
    }
    getToken() {
        let cookie = this.getTokenFromCookie(this._localStorageTokenName, document.cookie);
        if (!cookie) {
            cookie = this.getTokenFromLocalStorage(this._localStorageTokenName);
        }
        return cookie ? cookie : null;
    }
    setToken(token) {
        return localStorage.setItem(this._localStorageTokenName, token);
    }
    clearToken() {
        localStorage.removeItem(this._localStorageTokenName);
    }
}
exports.TokenService = TokenService;
